function [W, LAT, LON] = get_Euler_vector(plosca, model)
    % GET_EULER_VECTOR funkcija vrne Eulerjev vektor za podano tektonsko ploščo in podan model gibanja tektonskih plošč
    %   
    %   [W, LAT, LON] = get_Euler_vector( 'plosca', model = {'**NNR_NUVEL_1A**', 'NNR_MORVEL56', 'ITRF2014_PMM'} )
    %   
    %   VHODNI PARAMETRI:
    %     plosca ... ustrezna kratica tektonske plošče
    %     model  ... ime modela gibanja tektonskih plošč (NNR_NUVEL_1A / NNR_MORVEL56 / ITRF2014_PMM)
    %
    %   IZHODNI PARAMETRI -> EULERJEV VEKTOR:
    %     W   ... kotna hitrost [deg/Myr]
    %     LAT ... geografska širina Eulerjevega pola [deg]
    %     LON ... geografska dolžina Eulerjevega pola [deg]
    %
    %   AVTOR: Klemen Ritlop
    %   2023-02-20
    
    arguments
        plosca string
        model  string {mustBeMember(model, ["NNR_NUVEL_1A", "NNR_MORVEL56", "ITRF2014_PMM", "NUVEL_1_REL"])} = "NNR-NUVEL_1A"
    end
    
    % za primer, če nek model nima definiranih plošč po celotni površini Zemlje (npr. ITRF2014_PMM)
    if plosca == "null"
        W = 0; LAT = 0; LON = 0;
        return
    end

    switch model

        case "NNR_NUVEL_1A"
            switch plosca
                case "AFRC"; ev = [0.291,  50.6,  -74.0];
                case "ANTA"; ev = [0.238,  63.0, -115.8];
                case "ARAB"; ev = [0.543,  45.0,   -4.5];
                case "AUST"; ev = [0.646,  33.9,   33.2];
                case "CARB"; ev = [0.214,  25.0,  -93.0];
                case "COCO"; ev = [1.510,  24.5, -115.8];
                case "EURA"; ev = [0.234,  50.6, -112.3];
                case "INDI"; ev = [0.545,  45.5,    0.3];
                case "NAZC"; ev = [0.743,  47.8, -100.1];
                case "NOAM"; ev = [0.207,  -2.4,  -85.9];
                case "SOAM"; ev = [0.116, -25.3, -124.4];
                case "PHIL"; ev = [0.900, -38.0,  -35.4];
                case "PCFC"; ev = [0.641, -63.0,  107.3];
                otherwise;   error("Model %s ne vsebuje tektonske plosce %s", model, plosca)
            end
                
        case "NNR_MORVEL56"
            switch plosca
                case "am"; ev = [ 0.297,  63.17, -122.82];
                case "an"; ev = [ 0.250,  65.42, -118.11];
                case "ar"; ev = [ 0.559,  48.88,   -8.49];
                case "au"; ev = [ 0.632,  33.86,   37.94];
                case "cp"; ev = [ 0.608,  44.44,   23.09];
                case "ca"; ev = [ 0.286,  35.20,  -92.62];
                case "co"; ev = [ 1.198,  26.93, -124.31];
                case "eu"; ev = [ 0.223,  48.85, -106.50];
                case "in"; ev = [ 0.544,  50.37,   -3.29];
                case "jf"; ev = [ 0.951, -38.31,   60.04];
                case "lw"; ev = [ 0.286,  51.89,  -69.52];
                case "mq"; ev = [ 1.144,  49.19,   11.05];
                case "nz"; ev = [ 0.696,  46.23, -101.06];
                case "na"; ev = [ 0.209,  -4.85,  -80.64];
                case "nb"; ev = [ 0.292,  47.68,  -68.44];
                case "pa"; ev = [ 0.651, -63.58,  114.70];
                case "ps"; ev = [ 0.910, -46.02,  -31.36];
                case "ri"; ev = [ 4.536,  20.25, -107.29];
                case "sw"; ev = [ 1.362, -29.94,  -36.87];
                case "sc"; ev = [ 0.146,  22.52, -106.15];
                case "sm"; ev = [ 0.339,  49.95,  -84.52];
                case "sa"; ev = [ 0.109, -22.62, -112.83];
                case "su"; ev = [ 0.337,  50.06,  -95.02];
                case "sr"; ev = [ 0.107, -32.50, -111.32];
                case "yz"; ev = [ 0.334,  63.03, -116.62];
                case "AS"; ev = [ 0.124,  19.43,  122.87];
                case "AP"; ev = [ 0.488,  -6.58,  -83.98];
                case "AT"; ev = [ 1.210,  40.11,   26.66];
                case "BR"; ev = [ 0.490, -63.74,  142.06];
                case "BS"; ev = [ 2.475,  -1.49,  121.64];
                case "BH"; ev = [ 0.799, -40.00,  100.50];
                case "BU"; ev = [ 2.229,  -6.13,  -78.10];
                case "CL"; ev = [ 0.607, -72.78,   72.05];
                case "CR"; ev = [ 3.923, -20.40,  170.53];
                case "EA"; ev = [11.334,  24.97,   67.53];
                case "FT"; ev = [ 5.101, -16.33,  178.07];
                case "GP"; ev = [ 5.487,   2.53,   81.18];
                case "JZ"; ev = [22.368,  34.25,   70.74];
                case "KE"; ev = [ 2.347,  39.99,    6.46];
                case "MN"; ev = [51.569,  -3.67,  150.27];
                case "MO"; ev = [ 0.774,  14.25,   92.67];
                case "MA"; ev = [ 1.306,  11.05,  137.84];
                case "MS"; ev = [ 3.566,   2.15,  -56.09];
                case "NH"; ev = [ 2.469,   0.57,   -6.60];
                case "NI"; ev = [ 3.314,  -3.29, -174.49];
                case "ND"; ev = [ 0.116,  17.73, -122.68];
                case "NB"; ev = [ 0.856, -45.04,  127.64];
                case "OK"; ev = [ 0.229,  30.30,  -92.28];
                case "ON"; ev = [ 2.539,  36.12,  137.92];
                case "PM"; ev = [ 0.317,  31.35, -113.90];
                case "SL"; ev = [ 0.268,  50.71, -143.47];
                case "SS"; ev = [ 1.703,  -2.87,  130.62];
                case "SB"; ev = [ 8.111,   6.88,  -31.89];
                case "TI"; ev = [ 1.864,  -4.44,  113.50];
                case "TO"; ev = [ 8.942,  25.87,    4.48];
                case "WL"; ev = [ 1.744,   0.10,  128.52];
                otherwise; error("Model %s ne vsebuje tektonske plosce %s", model, plosca)
            end

        case "ITRF2014_PMM"
            switch plosca
                case "ANTA"; ev = [0.2191,  58.8482, -127.4316];
                case "ARAB"; ev = [0.5149,  51.1764,   -6.7214];
                case "AUST"; ev = [0.6306,  32.3584,   38.0532];
                case "EURA"; ev = [0.2609,  55.0699,  -99.0945];
                case "INDI"; ev = [0.5156,  51.5617,   -0.2482];
                case "NAZC"; ev = [0.6291,  45.7782, -102.1708];
                case "NOAM"; ev = [0.1937,  -5.1839,  -88.0194];
                case "NUBI"; ev = [0.2670,  49.6863,  -80.8406];
                case "PCFC"; ev = [0.6786, -62.6052,  111.3376];
                case "SOAM"; ev = [0.1189, -19.0975, -131.8924];
                case "SOMA"; ev = [0.3318,  47.7430,  -98.6648];
                otherwise; error("Model %s ne vsebuje tektonske plosce %s", model, plosca)
            end
        
        case "NUVEL_1_REL"
            switch plosca
                case "AFRC-ANTA"; ev = [0.13,   5.6,  -39.2];
                case "AFRC-EURA"; ev = [0.13,  21.0,  -20.6];
                case "AFRC-NOAM"; ev = [0.25,  78.8,   38.3];
                case "AFRC-SOAM"; ev = [0.32,  62.5,  -39.4];
                case "AUST-ANTA"; ev = [0.68,  13.2,   38.2];
                case "PCFC-ANTA"; ev = [0.91, -64.3,   96.0];
                case "SOAM-ANTA"; ev = [0.27, -86.4,  139.3];
                case "ARAB-EURA"; ev = [0.52,  24.6,   13.7];
                case "INDI-EURA"; ev = [0.53,  24.4,   17.7];
                case "EURA-NOAM"; ev = [0.22,  62.4,  135.8];
                case "EURA-PCFC"; ev = [0.90,  61.1,  -85.8];
                case "PCFC-AUST"; ev = [1.12, -60.1, -178.3];
                case "NOAM-PCFC"; ev = [0.78,  48.7,  -78.2];
                case "COCO-NOAM"; ev = [1.42,  27.9, -120.7];
                case "NAZC-PCFC"; ev = [1.42,  55.6,   90.1];
                case "NAZC-SOAM"; ev = [0.76,  56.0,  -94.0];
                % Po potrebi dopolni z obratnimi pari.
                otherwise; error("Model %s ne vsebuje para tektonskih plosc %s. Morda sem pozabil vnesti Eulerjeve vektorje za obratne pare plosc.", model, plosca)
            end    
    end   
    
    W = ev(1);
    LAT = ev(2);
    LON = ev(3);

end
    